import fs from "fs";
import path from "path";

function checkIfFileExists(file: string): boolean {
  try {
    fs.accessSync(file, fs.constants.F_OK);
    return true;
  } catch (err) {
    return false;
  }
}

function readFileContents(filePath: string): string | any {
  try {
    let fileContents: string = fs.readFileSync(filePath, "utf-8");
    return fileContents;
  } catch (err) {
    return null;
  }
}

function writeFileContents(
  filePath: string,
  content: string,
  writeOptions: Object = {}
): void | string | Object {
  const directoryPath: string = path.dirname(filePath);

  // Check if the directory exists
  if (!fs.existsSync(directoryPath)) {
    fs.mkdirSync(directoryPath, { recursive: true });
  }

  try {
    fs.writeFileSync(`${filePath}`, content, writeOptions);
  } catch (err) {
    throw new Error(err);
  }
}

function deleteFile(filePath: string): void | string | Object {
  if (checkIfFileExists(filePath)) {
    try {
      fs.unlinkSync(filePath);
    } catch (err) {
      throw new Error(`Error while deleting the test data file: ${filePath}`);
    }
  }
}

function deleteFolder(folderPath: string): void | string | Object {
  if (fs.existsSync(folderPath)) {
    try {
      fs.rmdirSync(folderPath, { recursive: true });
    } catch (err) {
      throw new Error(`Error while deleting the test data file: ${folderPath}`);
    }
  }
}

export {
  checkIfFileExists,
  readFileContents,
  writeFileContents,
  deleteFile,
  deleteFolder,
};
